@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::errno;
 use strict;
 use Acme::MetaSyntactic::MultiList;
 our @ISA     = qw( Acme::MetaSyntactic::MultiList );
-our $VERSION = '1.002';
+our $VERSION = '1.003';
 
 use Errno ();
 
@@ -38,6 +38,12 @@ Philippe Bruhat (BooK)
 
 =item *
 
+2013-05-13 - v1.003
+
+New release without any code change. (Just a F<Changes> change.)
+
+=item *
+
 2012-07-23 - v1.002
 
 Fix in the documentation CHANGES section.
